pub struct ListPartsPaginatorItems(/* private fields */);Expand description
Flattened paginator for ListPartsPaginator
This is created with .items()
Implementations
Sourceimpl ListPartsPaginatorItems
impl ListPartsPaginatorItems
Sourcepub fn send(
self,
) -> PaginationStream<Result<Part, SdkError<ListPartsError, HttpResponse>>>
pub fn send( self, ) -> PaginationStream<Result<Part, SdkError<ListPartsError, HttpResponse>>>
Create the pagination stream
Note: No requests will be dispatched until the stream is used
(e.g. with the .next().await method).
To read the entirety of the paginator, use .collect::<Result<Vec<_>, _>().